##  Customizing the Side Panel
To customize which fields and attributes are displayed in the side panel:
  1. Open a diagram and choose a fact sheet.
  2. In the side panel, choose Configure Content and add the desired fields.
  3. Choose Apply.
The changes are applied to the side panel.
  4. Optional: To ensure that the added fields are always visible when you reopen the diagram, choose Save from the dropdown.
